<?php

namespace Offerte\Offerte\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Offerte\Offerte\Http\Requests\ResumeRequest;
use Offerte\Offerte\Interfaces\ResumeRepositoryInterface;
use Offerte\Offerte\Models\Resume;
use Offerte\Offerte\Forms\Resume as Form;

/**
 * APIController  class for resume.
 */
class ResumeAPIController extends BaseController
{

    /**
     * Initialize resume resource controller.
     *
     * @param type ResumeRepositoryInterface $resume
     *
     * @return null
     */
    public function __construct(ResumeRepositoryInterface $resume)
    {
        parent::__construct();
        $this->repository = $resume;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Offerte\Offerte\Repositories\Criteria\ResumeResourceCriteria::class);
    }

    /**
     * Display a list of resume.
     *
     * @return Response
     */
    public function index(ResumeRequest $request)
    {
        return $this->repository
            ->setPresenter(\Offerte\Offerte\Repositories\Presenter\ResumePresenter::class)
            ->paginate();
    }

    /**
     * Display resume.
     *
     * @param Request $request
     * @param Model   $resume
     *
     * @return Response
     */
    public function show(ResumeRequest $request, Resume $resume)
    {
        return $resume->setPresenter(\Offerte\Offerte\Repositories\Presenter\ResumeListPresenter::class);
        ;
    }

    /**
     * Create new resume.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ResumeRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('offerte::resume.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('offerte/resume/' . $resume->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('offerte/resume');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the resume.
     *
     * @param Request $request
     * @param Model   $resume
     *
     * @return Response
     */
    public function update(ResumeRequest $request, Resume $resume)
    {
        try {
            $data = $request->all();

            $resume->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('offerte::resume.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('offerte/resume/' . $resume->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('offerte/resume/' . $resume->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the resume.
     *
     * @param Model   $resume
     *
     * @return Response
     */
    public function destroy(ResumeRequest $request, Resume $resume)
    {
        try {
            $resume->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('offerte::resume.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('offerte/resume/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('offerte/resume/' . $resume->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
