<?php

namespace Offerte\Offerte\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Offerte\Offerte\Http\Requests\ResumeRequest;
use Offerte\Offerte\Models\Resume;

/**
 * Admin web controller class.
 */
class ResumeWorkflowController extends BaseController
{

    /**
     * Workflow controller function for resume.
     *
     * @param Model   $resume
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ResumeRequest $request, Resume $resume, $step)
    {

        try {

            $resume->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('offerte::resume.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/resume/resume/' . $resume->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/resume/resume/' . $resume->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for resume.
     *
     * @param Model   $resume
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Resume $resume, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $resume->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('offerte::resume.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('offerte::admin.resume.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('offerte::admin.resume.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('offerte::admin.resume.message', $data)->render();

        }

    }
}
