<?php

namespace Offerte\Offerte\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Offerte\Offerte\Http\Requests\TestModuleRequest;
use Offerte\Offerte\Interfaces\TestModuleRepositoryInterface;
use Offerte\Offerte\Models\TestModule;
use Offerte\Offerte\Forms\TestModule as Form;

/**
 * APIController  class for test_module.
 */
class TestModuleAPIController extends BaseController
{

    /**
     * Initialize test_module resource controller.
     *
     * @param type TestModuleRepositoryInterface $test_module
     *
     * @return null
     */
    public function __construct(TestModuleRepositoryInterface $test_module)
    {
        parent::__construct();
        $this->repository = $test_module;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Offerte\Offerte\Repositories\Criteria\TestModuleResourceCriteria::class);
    }

    /**
     * Display a list of test_module.
     *
     * @return Response
     */
    public function index(TestModuleRequest $request)
    {
        return $this->repository
            ->setPresenter(\Offerte\Offerte\Repositories\Presenter\TestModulePresenter::class)
            ->paginate();
    }

    /**
     * Display test_module.
     *
     * @param Request $request
     * @param Model   $test_module
     *
     * @return Response
     */
    public function show(TestModuleRequest $request, TestModule $test_module)
    {
        return $test_module->setPresenter(\Offerte\Offerte\Repositories\Presenter\TestModuleListPresenter::class);
        ;
    }

    /**
     * Create new test_module.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TestModuleRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('offerte::test_module.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('offerte/test_module/' . $test_module->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('offerte/test_module');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the test_module.
     *
     * @param Request $request
     * @param Model   $test_module
     *
     * @return Response
     */
    public function update(TestModuleRequest $request, TestModule $test_module)
    {
        try {
            $data = $request->all();

            $test_module->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('offerte::test_module.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('offerte/test_module/' . $test_module->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('offerte/test_module/' . $test_module->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the test_module.
     *
     * @param Model   $test_module
     *
     * @return Response
     */
    public function destroy(TestModuleRequest $request, TestModule $test_module)
    {
        try {
            $test_module->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('offerte::test_module.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('offerte/test_module/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('offerte/test_module/' . $test_module->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
