<?php

namespace Offerte\Offerte\Policies;

use Litepie\User\Contracts\UserPolicy;
use Offerte\Offerte\Models\TestModule;

class TestModulePolicy
{

    /**
     * Determine if the given user can view the test_module.
     *
     * @param UserPolicy $user
     * @param TestModule $test_module
     *
     * @return bool
     */
    public function view(UserPolicy $user, TestModule $test_module)
    {
        if ($user->canDo('offerte.test_module.view') && $user->isAdmin()) {
            return true;
        }

        return $test_module->user_id == user_id() && $test_module->user_type == user_type();
    }

    /**
     * Determine if the given user can create a test_module.
     *
     * @param UserPolicy $user
     * @param TestModule $test_module
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('offerte.test_module.create');
    }

    /**
     * Determine if the given user can update the given test_module.
     *
     * @param UserPolicy $user
     * @param TestModule $test_module
     *
     * @return bool
     */
    public function update(UserPolicy $user, TestModule $test_module)
    {
        if ($user->canDo('offerte.test_module.edit') && $user->isAdmin()) {
            return true;
        }

        return $test_module->user_id == user_id() && $test_module->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given test_module.
     *
     * @param UserPolicy $user
     * @param TestModule $test_module
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, TestModule $test_module)
    {
        return $test_module->user_id == user_id() && $test_module->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given test_module.
     *
     * @param UserPolicy $user
     * @param TestModule $test_module
     *
     * @return bool
     */
    public function verify(UserPolicy $user, TestModule $test_module)
    {
        if ($user->canDo('offerte.test_module.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given test_module.
     *
     * @param UserPolicy $user
     * @param TestModule $test_module
     *
     * @return bool
     */
    public function approve(UserPolicy $user, TestModule $test_module)
    {
        if ($user->canDo('offerte.test_module.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
