<?php

namespace Offerte\Offerte\Providers;

use Illuminate\Support\ServiceProvider;

class OfferteServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'offerte');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'offerte');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerOfferte();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerOfferte()
    {
        $this->app->bind('offerte', function($app) {
            return new Offerte($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Offerte', 'Lavalite\Offerte\Facades\Offerte');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('offerte.offerte', function ($app) {
            return $this->app->make('Offerte\Offerte\Offerte');
        });

        // Bind TestModule to repository
        $this->app->bind(
            'Offerte\Offerte\Interfaces\TestModuleRepositoryInterface',
            \Offerte\Offerte\Repositories\Eloquent\TestModuleRepository::class
        );
        // Bind Resume to repository
        $this->app->bind(
            'Offerte\Offerte\Interfaces\ResumeRepositoryInterface',
            \Offerte\Offerte\Repositories\Eloquent\ResumeRepository::class
        );

        $this->app->register(\Offerte\Offerte\Providers\AuthServiceProvider::class);
                $this->app->register(\Offerte\Offerte\Providers\EventServiceProvider::class);
        
        $this->app->register(\Offerte\Offerte\Providers\RouteServiceProvider::class);
                // $this->app->register(\Offerte\Offerte\Providers\WorkflowServiceProvider::class);
            }

    /**
     * Merges user's and offerte's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'offerte.offerte'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeOfferte::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['offerte.offerte'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('offerte/offerte.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/offerte')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/offerte')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
